@@ -1,26 +1,32 @@
 //! @file mp-gamic.c
 //! @author J. Marcel van der Veer
-//
+
 //! @section Copyright
-//
-// This file is part of Algol68G - an Algol 68 compiler-interpreter.
-// Copyright 2001-2023 J. Marcel van der Veer <algol68g@xs4all.nl>.
-//
+//!
+//! This file is part of Algol68G - an Algol 68 compiler-interpreter.
+//! Copyright 2001-2025 J. Marcel van der Veer [algol68g@xs4all.nl].
+
 //! @section License
-//
-// This program is free software; you can redistribute it and/or modify it 
-// under the terms of the GNU General Public License as published by the 
-// Free Software Foundation; either version 3 of the License, or 
-// (at your option) any later version.
-//
-// This program is distributed in the hope that it will be useful, but 
-// WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY 
-// or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for 
-// more details. You should have received a copy of the GNU General Public 
-// License along with this program. If not, see <http://www.gnu.org/licenses/>.
+//!
+//! This program is free software; you can redistribute it and/or modify it 
+//! under the terms of the GNU General Public License as published by the 
+//! Free Software Foundation; either version 3 of the License, or 
+//! (at your option) any later version.
+//!
+//! This program is distributed in the hope that it will be useful, but 
+//! WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY 
+//! or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for 
+//! more details. You should have received a copy of the GNU General Public 
+//! License along with this program. If not, see [http://www.gnu.org/licenses/].
+
+//! @section Synopsis
+//!
+//! [LONG] LONG REAL generalised incomplete gamma function.
 
 // Generalised incomplete gamma code in this file was downloaded from 
-//   http://helios.mi.parisdescartes.fr/~rabergel/
+//
+//   [http://helios.mi.parisdescartes.fr/~rabergel/]
+//
 // and adapted for Algol 68 Genie.
 //
 // Reference:
@@ -36,48 +42,38 @@
 // This file is a part of the DELTAGAMMAINC software, dedicated to the
 // computation of a generalized incomplete gammafunction. See the Companion paper
 // for a complete description of the algorithm.
-//
 // ``Fast and accurate evaluation of a generalized incomplete gamma function''
 // (Rémy Abergel, Lionel Moisan), preprint MAP5 nº2016-14, revision 1.
-//
 // This program is free software: you can redistribute it and/or modify it under
 // the terms of the GNU General Public License as published by the Free Software
 // Foundation, either version 3 of the License, or (at your option) any later
 // version.
-//
 // This program is distributed in the hope that it will be useful, but WITHOUT
 // ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 // FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
 // details.
 //
 // You should have received a copy of the GNU General Public License along with
-// this program.  If not, see <http://www.gnu.org/licenses/>.
+// this program.  If not, see [http://www.gnu.org/licenses/].
 
 // References
-//
 //   R. Abergel and L. Moisan. 2016. Fast and accurate evaluation of a
 //   generalized incomplete gamma function, preprint MAP5 nº2016-14, revision 1
-//
 //   Rémy Abergel, Lionel Moisan. Fast and accurate evaluation of a
 //   generalized incomplete gamma function. 2019. hal-01329669v2
-//
 //   F. W. J. Olver, D. W. Lozier, R. F. Boisvert, and C. W. Clark
 //   (Eds.). 2010. NIST Handbook of Mathematical Functions. Cambridge University
-//   Press. (see online version at [[http://dlmf.nist.gov/]])
-//
+//   Press. (see online version at [http://dlmf.nist.gov/])
 //   W. H. Press, S. A. Teukolsky, W. T. Vetterling, and
 //   B. P. Flannery. 1992. Numerical recipes in C: the art of scientific
 //   computing (2nd ed.).
-//
 //   G. R. Pugh, 2004. An analysis of the Lanczos Gamma approximation (phd
 //   thesis)
 
 #include "a68g.h"
 #include "a68g-genie.h"
-#include "a68g-prelude.h"
-#include "a68g-double.h"
 #include "a68g-mp.h"
-#include "a68g-lib.h"
+#include "a68g-prelude.h"
 
 // Processing time of Abergel's algorithms rises steeply with precision.
 #define MAX_PRECISION (LONG_LONG_MP_DIGITS + LONG_MP_DIGITS)
@@ -160,7 +156,7 @@ MP_T *G_cfrac_lower_mp (NODE_T *q, MP_T * Gcfrac, MP_T *p, MP_T *x, int digs)
     (void) mul_mp (q, f, f, del, digs);
 //  n++;
     (void) plus_one_mp (q, n, n, digs);
-//  while ((fabsq (del - 1) >= EPS) && (n < ITMAX));
+//  while ((fabs_double (del - 1) >= EPS) && (n < ITMAX));
     (void) minus_one_mp (q, trm, del, digs);
     (void) abs_mp (q, trm, trm, digs);
     (void) ge_mp (q, &ge, trm, eps, digs);
@@ -174,7 +170,6 @@ MP_T *G_cfrac_lower_mp (NODE_T *q, MP_T * Gcfrac, MP_T *p, MP_T *x, int digs)
 
 //! @brief compute the G-function in the domain x > p using a
 // continued fraction.
-//
 // 0 < p < x, or x = +infinity
 
 MP_T *G_cfrac_upper_mp (NODE_T *q, MP_T * Gcfrac, MP_T *p, MP_T *x, int digs)
@@ -266,7 +261,7 @@ MP_T *G_cfrac_upper_mp (NODE_T *q, MP_T * Gcfrac, MP_T *p, MP_T *x, int digs)
     (void) plus_one_mp (q, i, i, digs);
 //  n++;
     (void) plus_one_mp (q, n, n, digs);
-//  while ((fabsq (del - 1) >= EPS) && (n < ITMAX));
+//  while ((fabs_double (del - 1) >= EPS) && (n < ITMAX));
     (void) minus_one_mp (q, trm, del, digs);
     (void) abs_mp (q, trm, trm, digs);
     (void) ge_mp (q, &ge, trm, eps, digs);
@@ -286,7 +281,6 @@ MP_T *G_cfrac_upper_mp (NODE_T *q, MP_T * Gcfrac, MP_T *p, MP_T *x, int digs)
 //! @brief compute the G-function in the domain x < 0 and |x| < max (1,p-1)
 // using a recursive integration by parts relation.
 // This function cannot be used when mu > 0.
-//
 // p > 0, integer; x < 0, |x| < max (1,p-1)
 
 MP_T *G_ibp_mp (NODE_T *q, MP_T * Gibp, MP_T *p, MP_T *x, int digs)
@@ -294,7 +288,7 @@ MP_T *G_ibp_mp (NODE_T *q, MP_T * Gibp, MP_T *p, MP_T *x, int digs)
   ADDR_T pop_sp = A68_SP;
   MP_T *trm = nil_mp (q, digs), *trn = nil_mp (q, digs);
   MP_T *eps = EPS (q, digs);
-// t = fabsq (x);
+// t = fabs_double (x);
   MP_T *t = nil_mp (q, digs);
   (void) abs_mp (q, x, x, digs);
 // tt = 1 / (t * t);
@@ -318,8 +312,7 @@ MP_T *G_ibp_mp (NODE_T *q, MP_T * Gibp, MP_T *p, MP_T *x, int digs)
   (void) mul_mp (q, s, c, trm, digs);
 // l = 0;
   MP_T *l = nil_mp (q, digs);
-//
-  BOOL_T cont = A68_TRUE, stop;
+  BOOL_T cont = A68_TRUE, stop = A68_TRUE;
   MP_T *del = nil_mp (q, digs);
   while (cont) {
 //  c *= d * (d - 1) * tt;
@@ -336,14 +329,14 @@ MP_T *G_ibp_mp (NODE_T *q, MP_T * Gibp, MP_T *p, MP_T *x, int digs)
     (void) add_mp (q, s, s, del, digs);
 //  l++;
     (void) plus_one_mp (q, l, l, digs);
-//  stop = fabsq (del) < fabsq (s) * EPS;
+//  stop = fabs_double (del) < fabs_double (s) * EPS;
     (void) abs_mp (q, trm, del, digs);
     (void) abs_mp (q, trn, s, digs);
     (void) mul_mp (q, trn, trn, eps, digs);
     A68_BOOL lt;
     (void) lt_mp (q, &lt, trm, trn, digs);
     stop = VALUE (&lt);
-//while ((l < floorq ((p - 2) / 2)) && !stop);
+//while ((l < floor_double ((p - 2) / 2)) && !stop);
     (void) sub_mp (q, trm, p, two, digs);
     (void) half_mp (q, trm, trm, digs);
     (void) floor_mp (q, trm, trm, digs);
@@ -356,7 +349,7 @@ MP_T *G_ibp_mp (NODE_T *q, MP_T * Gibp, MP_T *p, MP_T *x, int digs)
     (void) mul_mp (q, trm, d, trm, digs);
     (void) add_mp (q, s, s, trm, digs);
   }
-// Gibp = ((odd ? -1 : 1) * expq (-t + lgammaq (p) - (p - 1) * logq (t)) + s) / t;
+// Gibp = ((odd ? -1 : 1) * exp_double (-t + lgammaq (p) - (p - 1) * log_double (t)) + s) / t;
   (void) ln_mp (q, trn, t, digs);
   (void) minus_one_mp (q, trm, p, digs);
   (void) mul_mp (q, trm, trm, trn, digs);
@@ -397,12 +390,10 @@ MP_T *plim_mp (NODE_T *p, MP_T *z, MP_T *x, int digs)
 }
 
 //! @brief compute G : (p,x) --> R defined as follows
-//
 // if x <= p:
 //   G(p,x) = exp (x-p*ln (|x|)) * integral of s^{p-1} * exp (-sign (x)*s) ds from s = 0 to |x|
 // otherwise:
 //   G(p,x) = exp (x-p*ln (|x|)) * integral of s^{p-1} * exp (-s) ds from s = x to infinity
-//
 //   p > 0; x is a real number or +infinity.
 
 void G_func_mp (NODE_T *q, MP_T * G, MP_T *p, MP_T *x, int digs)
@@ -437,7 +428,6 @@ static inline int IX (int n, int digs) {
 void mp_romberg_iterations 
   (NODE_T *q, MP_T *R, MP_T *sigma, INT_T n, MP_T *x, MP_T *y, MP_T *mu, MP_T *p, MP_T *h, MP_T *pow2, int digs)
 {
-  INT_T m;
   MP_T *trm = nil_mp (q, digs), *trn = nil_mp (q, digs);
   MP_T *sum = nil_mp (q, digs), *xx = nil_mp (q, digs);
   INT_T adr0_prev = ((n - 1) * n) / 2;
@@ -454,7 +444,7 @@ void mp_romberg_iterations
     (void) div_mp (q, trm, trm, pow2, digs);
     (void) half_mp (q, trm, trm, digs);
     (void) add_mp (q, xx, x, trm, digs);
-//  sum += exp (-mu * xx + (p - 1) * a68_ln (xx) - sigma);
+//  sum += exp (-mu * xx + (p - 1) * a68_ln_real (xx) - sigma);
     (void) ln_mp (q, trn, xx, digs);
     (void) minus_one_mp (q, trm, p, digs);
     (void) mul_mp (q, trm, trm, trn, digs);
@@ -473,7 +463,7 @@ void mp_romberg_iterations
   (void) add_mp (q, &R[IX (adr0, digs)], trm, trn, digs);
 // REAL_T pow4 = 4;
   MP_T *pow4 = lit_mp (q, 4, 0, digs);
-  for (m = 1; m <= n; m++) {
+  for (int m = 1; m <= n; m++) {
 //  R[adr0 + m] = (pow4 * R[adr0 + (m - 1)] - R[adr0_prev + (m - 1)]) / (pow4 - 1);
     (void) mul_mp (q, trm, pow4, &R[IX (adr0 + m - 1, digs)], digs);
     (void) sub_mp (q, trm, trm, &R[IX (adr0_prev + m - 1, digs)], digs);
@@ -552,18 +542,13 @@ void mp_romberg_estimate (NODE_T *q, MP_T * rho, MP_T * sigma, MP_T *x, MP_T *y,
 }
 
 //! @brief compute generalized incomplete gamma function I_{x,y}^{mu,p}
-//
 //   I_{x,y}^{mu,p} = integral from x to y of s^{p-1} * exp (-mu*s) ds
-//
 // This procedure computes (rho, sigma) described below.
 // The approximated value of I_{x,y}^{mu,p} is I = rho * exp (sigma)
-//
 //   mu is a real number non equal to zero 
 //     (in general we take mu = 1 or -1 but any nonzero real number is allowed)
-//
 //   x, y are two numbers with 0 <= x <= y <= +infinity,
 //     (the setting y=+infinity is allowed only when mu > 0)
-//
 //   p is a real number > 0, p must be an integer when mu < 0.
 
 void Dgamic_mp (NODE_T *q, MP_T * rho, MP_T * sigma, MP_T *x, MP_T *y, MP_T *mu, MP_T *p, int digs)
@@ -601,7 +586,7 @@ void Dgamic_mp (NODE_T *q, MP_T * rho, MP_T * sigma, MP_T *x, MP_T *y, MP_T *mu,
   MP_T *mux = nil_mp (q, digs);
   MP_T *muy = nil_mp (q, digs);
 // Initialization
-// nx = (a68_isinf (x) ? a68_neginf () : -mu * x + p * ln (x));
+// nx = (a68_isinf_real (x) ? a68_neginf_double_real () : -mu * x + p * ln (x));
   if (PLUS_INF_MP (x)) {
     SET_MP_ZERO (mx, digs);
     MP_STATUS (nx) = (UNSIGNED_T) MP_STATUS (nx) | MINUS_INF_MASK;
@@ -612,7 +597,7 @@ void Dgamic_mp (NODE_T *q, MP_T * rho, MP_T * sigma, MP_T *x, MP_T *y, MP_T *mu,
     (void) mul_mp (q, nx, p, nx, digs);
     (void) sub_mp (q, nx, nx, mux, digs);
   }
-// ny = (a68_isinf (y) ? a68_neginf () : -mu * y + p * ln (y));
+// ny = (a68_isinf_real (y) ? a68_neginf_double_real () : -mu * y + p * ln (y));
   if (PLUS_INF_MP (y)) {
     SET_MP_ZERO (my, digs);
     MP_STATUS (ny) = (UNSIGNED_T) MP_STATUS (ny) | MINUS_INF_MASK;
@@ -666,7 +651,7 @@ void Dgamic_mp (NODE_T *q, MP_T * rho, MP_T * sigma, MP_T *x, MP_T *y, MP_T *mu,
   if (VALUE (&lt)) {
 //  mA = 1;
     set_mp (mA, 1, 0, digs);
-//  nA = lgammaq (p) - p * logq (mu);
+//  nA = lgammaq (p) - p * log_double (mu);
     MP_T *lgam = nil_mp (q, digs);
     MP_T *lnmu = nil_mp (q, digs);
     (void) lngamma_mp (q, lgam, p, digs);
@@ -685,7 +670,7 @@ void Dgamic_mp (NODE_T *q, MP_T * rho, MP_T * sigma, MP_T *x, MP_T *y, MP_T *mu,
     } else {
       (void) move_mp (nB, ny, digs);
     }
-//  mB = mx * expq (nx - nB) + my * expq (ny - nB);
+//  mB = mx * exp_double (nx - nB) + my * exp_double (ny - nB);
     (void) sub_mp (q, trm, nx, nB, digs);
     (void) exp_mp (q, trm, trm, digs);
     (void) mul_mp (q, mB, mx, trm, digs);
@@ -703,7 +688,7 @@ void Dgamic_mp (NODE_T *q, MP_T * rho, MP_T * sigma, MP_T *x, MP_T *y, MP_T *mu,
   (void) move_mp (nB, nx, digs);
   compute:
 // Compute (rho,sigma) such that rho*exp (sigma) = A-B
-// 1. rho = mA - mB * expq (nB - nA);
+// 1. rho = mA - mB * exp_double (nB - nA);
   (void) sub_mp (q, trm, nB, nA, digs);
   (void) exp_mp (q, trm, trm, digs);
   (void) mul_mp (q, trm, mB, trm, digs);
@@ -711,7 +696,7 @@ void Dgamic_mp (NODE_T *q, MP_T * rho, MP_T * sigma, MP_T *x, MP_T *y, MP_T *mu,
 // 2. sigma = nA;
   (void) move_mp (sigma, nA, digs);
 // If the difference involved a significant loss of precision, compute Romberg estimate.
-// if (!isinfq (y) && ((*rho) / mA < TOL_DIFF)) {
+// if (!isinf_double (y) && ((*rho) / mA < TOL_DIFF)) {
   (void) div_mp (q, trm, rho, mA, digs);
   (void) lt_mp (q, &lt, trm, TOL_DIFF (q, digs), digs);
   if (!PLUS_INF_MP (y) && VALUE (&lt)) {
@@ -837,9 +822,10 @@ void genie_gamma_inc_gf_mp (NODE_T *p)
 
 void genie_gamma_inc_h_mp (NODE_T *p)
 {
-#if defined (HAVE_GNU_MPFR) && (A68_LEVEL >= 3)
-  genie_gamma_inc_mpfr (p);
-#else
-  genie_gamma_inc_f_mp (p);
-#endif
+// #if defined (HAVE_GNU_MPFR) && (A68_LEVEL >= 3)
+//   genie_gamma_inc_mpfr (p);
+// #else
+//   genie_gamma_inc_f_mp (p);
+// #endif
+   genie_gamma_inc_f_mp (p);
 }
