@@ -1,30 +1,33 @@
 //! @file mp-gamma.c
 //! @author J. Marcel van der Veer
-//
+
 //! @section Copyright
-//
-// This file is part of Algol68G - an Algol 68 compiler-interpreter.
-// Copyright 2001-2023 J. Marcel van der Veer <algol68g@xs4all.nl>.
-//
+//!
+//! This file is part of Algol68G - an Algol 68 compiler-interpreter.
+//! Copyright 2001-2025 J. Marcel van der Veer [algol68g@xs4all.nl].
+
 //! @section License
-//
-// This program is free software; you can redistribute it and/or modify it 
-// under the terms of the GNU General Public License as published by the 
-// Free Software Foundation; either version 3 of the License, or 
-// (at your option) any later version.
-//
-// This program is distributed in the hope that it will be useful, but 
-// WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY 
-// or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for 
-// more details. You should have received a copy of the GNU General Public 
-// License along with this program. If not, see <http://www.gnu.org/licenses/>.
+//!
+//! This program is free software; you can redistribute it and/or modify it 
+//! under the terms of the GNU General Public License as published by the 
+//! Free Software Foundation; either version 3 of the License, or 
+//! (at your option) any later version.
+//!
+//! This program is distributed in the hope that it will be useful, but 
+//! WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY 
+//! or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for 
+//! more details. You should have received a copy of the GNU General Public 
+//! License along with this program. If not, see [http://www.gnu.org/licenses/].
+
+//! @section Synopsis
+//!
+//! [LONG] LONG REAL error, gamma and beta functions.
 
 #include "a68g.h"
 #include "a68g-genie.h"
 #include "a68g-prelude.h"
 #include "a68g-double.h"
 #include "a68g-mp.h"
-#include "a68g-lib.h"
 
 //! @brief PROC (LONG REAL) LONG REAL erf
 
@@ -36,11 +39,11 @@ MP_T *erf_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
   } else {
     ADDR_T pop_sp = A68_SP;
 // Note we need double precision!
-    int gdigs = FUN_DIGITS (2 * digs), k = 1, sign;
-    BOOL_T go_on = A68_TRUE;
+    BOOL_T siga = A68_TRUE;
+    int sign = MP_SIGN (x);
+    int gdigs = FUN_DIGITS (2 * digs);
     MP_T *y_g = nil_mp (p, gdigs);
     MP_T *z_g = len_mp (p, x, digs, gdigs);
-    sign = MP_SIGN (x);
     (void) abs_mp (p, z_g, z_g, gdigs);
     (void) set_mp (y_g, gdigs * LOG_MP_RADIX, 0, gdigs);
     (void) sqrt_mp (p, y_g, y_g, gdigs);
@@ -57,7 +60,7 @@ MP_T *erf_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
       (void) mul_mp (p, y_g, z_g, z_g, gdigs);
       SET_MP_ONE (s_g, gdigs);
       SET_MP_ONE (t_g, gdigs);
-      for (k = 1; go_on; k++) {
+      for (int k = 1; siga; k++) {
         (void) mul_mp (p, t_g, y_g, t_g, gdigs);
         (void) div_mp_digit (p, t_g, t_g, (MP_T) k, gdigs);
         (void) div_mp_digit (p, u_g, t_g, (MP_T) (2 * k + 1), gdigs);
@@ -66,7 +69,7 @@ MP_T *erf_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
         } else {
           (void) sub_mp (p, s_g, s_g, u_g, gdigs);
         }
-        go_on = (MP_EXPONENT (s_g) - MP_EXPONENT (u_g)) < gdigs;
+        siga = (MP_EXPONENT (s_g) - MP_EXPONENT (u_g)) < gdigs;
       }
       (void) mul_mp (p, r_g, z_g, s_g, gdigs);
       (void) mul_mp_digit (p, r_g, r_g, 2, gdigs);
@@ -96,27 +99,27 @@ MP_T *erfc_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
 MP_T *inverf_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
 {
   ADDR_T pop_sp = A68_SP;
-  int gdigs, sign;
-  BOOL_T go_on = A68_TRUE;
+  int gdigs;
+  BOOL_T siga = A68_TRUE;
 // Precision adapts to the argument, but not too much.
 // If this is not precise enough, you need more digs
 // in your entire calculation, not just in this routine.
 // Calculate an initial Newton-Raphson estimate while at it.
 #if (A68_LEVEL >= 3)
-  DOUBLE_T y = ABS (mp_to_real_16 (p, x, digs));
-  if (y < erfq (5.0q)) {
-    y = inverf_real_16 (y);
+  DOUBLE_T y = ABS (mp_to_double (p, x, digs));
+  if (y < erf_double (5.0q)) {
+    y = inverf_double (y);
     gdigs = FUN_DIGITS (digs);
   } else {
     y = 5.0q;
     gdigs = FUN_DIGITS (2 * digs);
   }
   MP_T *z_g = nil_mp (p, gdigs);
-  (void) real_16_to_mp (p, z_g, y, gdigs);
+  (void) double_to_mp (p, z_g, y, gdigs);
 #else
   REAL_T y = ABS (mp_to_real (p, x, digs));
   if (y < erf (4.0)) {
-    y = a68_inverf (y);
+    y = a68_inverf_real (y);
     gdigs = FUN_DIGITS (digs);
   } else {
     y = 4.0;
@@ -127,7 +130,7 @@ MP_T *inverf_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
 #endif
   MP_T *x_g = len_mp (p, x, digs, gdigs);
   MP_T *y_g = nil_mp (p, gdigs);
-  sign = MP_SIGN (x);
+  int sign = MP_SIGN (x);
   (void) abs_mp (p, x_g, x_g, gdigs);
   SET_MP_ONE (y_g, gdigs);
   (void) sub_mp (p, y_g, x_g, y_g, gdigs);
@@ -145,7 +148,7 @@ MP_T *inverf_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
     (void) half_mp (p, p_g, p_g, gdigs);
 // nrdigs prevents end-less iteration
     int nrdigs;
-    for (nrdigs = 0; nrdigs < digs && go_on; nrdigs++) {
+    for (nrdigs = 0; nrdigs < digs && siga; nrdigs++) {
       (void) move_mp (y_g, z_g, gdigs);
       (void) erf_mp (p, f_g, z_g, gdigs);
       (void) sub_mp (p, f_g, f_g, x_g, gdigs);
@@ -157,9 +160,9 @@ MP_T *inverf_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
       (void) sub_mp (p, z_g, z_g, f_g, gdigs);
       (void) sub_mp (p, y_g, z_g, y_g, gdigs);
       if (IS_ZERO_MP (y_g)) {
-        go_on = A68_FALSE;
+        siga = A68_FALSE;
       } else {
-        go_on = ABS (MP_EXPONENT (y_g)) < digs;
+        siga = ABS (MP_EXPONENT (y_g)) < digs;
       }
     }
     (void) shorten_mp (p, z, digs, z_g, gdigs);
@@ -183,7 +186,6 @@ MP_T *inverfc_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
 // Reference: 
 //   John L. Spouge. "Computation of the Gamma, Digamma, and Trigamma Functions". 
 //   SIAM Journal on Numerical Analysis. 31 (3) [1994]
-//
 // Spouge's algorithm sums terms of greatly varying magnitude.
 
 #define GAMMA_PRECISION(z) (2 * (z))
@@ -215,8 +217,7 @@ void mp_gamma_table (NODE_T *p, int digs)
     MP_T *hlf = nil_mp (p, gdigs);
     MP_T *fac = lit_mp (p, 1, 0, gdigs);
     SET_MP_HALF (hlf, gdigs);
-    int k;
-    for (k = 1; k < b; k++) {
+    for (int k = 1; k < b; k++) {
       set_mp (dk, k, 0, gdigs);
       (void) sub_mp (p, ak, db, dk, gdigs);
       (void) sub_mp (p, dz, dk, hlf, gdigs);
@@ -225,7 +226,7 @@ void mp_gamma_table (NODE_T *p, int digs)
       (void) mul_mp (p, ck, ck, dz, gdigs);
       (void) div_mp (p, ck, ck, fac, gdigs);
       A68_MP (mp_gam_ck)[k] = (MP_T *) get_heap_space (SIZE_MP (gdigs));
-      (void) move_mp ((A68_MP(mp_gam_ck)[k]), ck, gdigs);
+      (void) move_mp ((A68_MP (mp_gam_ck)[k]), ck, gdigs);
       (void) mul_mp (p, fac, fac, dk, gdigs);
       (void) minus_mp (p, fac, fac, gdigs);
     }
@@ -241,8 +242,7 @@ MP_T *mp_spouge_sum (NODE_T *p, MP_T *sum, MP_T *x_g, int gdigs)
   MP_T *dz = nil_mp (p, gdigs);
   (void) move_mp (sum, A68_MP (mp_gam_ck)[0], gdigs);
 // Sum small to large to preserve precision.
-  int k;
-  for (k = a - 1; k > 0; k--) {
+  for (int k = a - 1; k > 0; k--) {
     set_mp (da, k, 0, gdigs);
     (void) add_mp (p, dz, x_g, da, gdigs);
     (void) div_mp (p, dz, A68_MP (mp_gam_ck)[k], dz, gdigs);
@@ -433,7 +433,7 @@ MP_T *beta_inc_mp (NODE_T * p, MP_T * z, MP_T * s, MP_T *t, MP_T *x, int digs)
   MP_T *u = lit_mp (p, 1, 0, gdigs);
   MP_T *v = nil_mp (p, gdigs);
   MP_T *w = nil_mp (p, gdigs);
-  for (INT_T N = 0; cont && N < lim; N++) {
+  for (int N = 0; cont && N < lim; N++) {
     if (N == 0) {
       SET_MP_ONE (T, gdigs);
     } else if (N % 2 == 0) {
