@@ -1,23 +1,27 @@
 //! @file mp-mpfr.c
 //! @author J. Marcel van der Veer
-//
+
 //! @section Copyright
-//
-// This file is part of Algol68G - an Algol 68 compiler-interpreter.
-// Copyright 2001-2023 J. Marcel van der Veer <algol68g@xs4all.nl>.
-//
+//!
+//! This file is part of Algol68G - an Algol 68 compiler-interpreter.
+//! Copyright 2001-2025 J. Marcel van der Veer [algol68g@xs4all.nl].
+
 //! @section License
-//
-// This program is free software; you can redistribute it and/or modify it 
-// under the terms of the GNU General Public License as published by the 
-// Free Software Foundation; either version 3 of the License, or 
-// (at your option) any later version.
-//
-// This program is distributed in the hope that it will be useful, but 
-// WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY 
-// or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for 
-// more details. You should have received a copy of the GNU General Public 
-// License along with this program. If not, see <http://www.gnu.org/licenses/>.
+//!
+//! This program is free software; you can redistribute it and/or modify it 
+//! under the terms of the GNU General Public License as published by the 
+//! Free Software Foundation; either version 3 of the License, or 
+//! (at your option) any later version.
+//!
+//! This program is distributed in the hope that it will be useful, but 
+//! WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY 
+//! or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for 
+//! more details. You should have received a copy of the GNU General Public 
+//! License along with this program. If not, see [http://www.gnu.org/licenses/].
+
+//! @section Synopsis
+//!
+//! [LONG] LONG REAL routines using GNU MPFR.
 
 #include "a68g.h"
 #include "a68g-genie.h"
@@ -31,8 +35,7 @@
 
 #define DEFAULT GMP_RNDN
 
-#define MPFR_REAL_BITS (REAL_MANT_DIG)
-#define MPFR_LONG_REAL_BITS (FLT128_MANT_DIG)
+#define MANT_BITS(n) ((int) round ((n) / log10 (2.0)))
 #define MPFR_MP_BITS (MANT_BITS (mpfr_digits ()))
 
 #define NO_MPFR ((mpfr_ptr) NULL)
@@ -55,16 +58,15 @@ void mp_to_mpfr (NODE_T * p, MP_T * z, mpfr_t * x, int digits)
 // This routine looks a lot like "strtod".
   (void) p;
   mpfr_set_ui (*x, 0, DEFAULT);
-  if (MP_EXPONENT (z) * (MP_T) LOG_MP_RADIX > (MP_T) REAL_MIN_10_EXP) {
-    int j, expo;
+  if (MP_EXPONENT (z) * (MP_T) LOG_MP_RADIX > (MP_T) A68_REAL_MIN_EXP) {
     BOOL_T neg = MP_DIGIT (z, 1) < 0;
     mpfr_t term, W;
     mpfr_inits2 (MPFR_MP_BITS, term, W, NO_MPFR);
     MP_DIGIT (z, 1) = ABS (MP_DIGIT (z, 1));
-    expo = (int) (MP_EXPONENT (z) * LOG_MP_RADIX);
+    int expo = (int) (MP_EXPONENT (z) * LOG_MP_RADIX);
     mpfr_set_ui (W, 10, DEFAULT);
     mpfr_pow_si (W, W, expo, DEFAULT);
-    for (j = 1; j <= digits; j++) {
+    for (int j = 1; j <= digits; j++) {
       mpfr_set_d (term, MP_DIGIT (z, j), DEFAULT);
       mpfr_mul (term, term, W, DEFAULT);
       mpfr_add (*x, *x, term, DEFAULT);
@@ -80,19 +82,18 @@ void mp_to_mpfr (NODE_T * p, MP_T * z, mpfr_t * x, int digits)
 
 MP_T *mpfr_to_mp (NODE_T * p, MP_T * z, mpfr_t * x, int digits)
 {
-  int j, k, sign_x, sum, W;
-  mpfr_t u, v, t;
   SET_MP_ZERO (z, digits);
   if (mpfr_zero_p (*x)) {
     return z;
   }
-  sign_x = mpfr_sgn (*x);
+  int sign_x = mpfr_sgn (*x);
+  mpfr_t u, v, t;
   mpfr_inits2 (MPFR_MP_BITS, t, u, v, NO_MPFR);
 // Scale to [0, 0.1>.
 // a = ABS (x);
   mpfr_set (u, *x, DEFAULT);
   mpfr_abs (u, u, DEFAULT);
-// expo = (int) log10q (a);
+// expo = (int) log10_double (a);
   mpfr_log10 (v, u, DEFAULT);
   INT_T expo = mpfr_get_si (v, DEFAULT);
 // v /= ten_up_double (expo);
@@ -105,9 +106,8 @@ MP_T *mpfr_to_mp (NODE_T * p, MP_T * z, mpfr_t * x, int digits)
     expo++;
   }
 // Transport digits of x to the mantissa of z.
-  sum = 0;
-  W = (MP_RADIX / 10);
-  for (k = 0, j = 1; j <= digits && k < mpfr_digits (); k++) {
+  INT_T sum = 0, W = (MP_RADIX / 10); int j = 1;
+  for (int k = 0; j <= digits && k < mpfr_digits (); k++) {
     mpfr_mul_ui (t, u, 10, DEFAULT);
     mpfr_floor (v, t);
     mpfr_frac (u, t, DEFAULT);
@@ -133,15 +133,14 @@ MP_T *mpfr_to_mp (NODE_T * p, MP_T * z, mpfr_t * x, int digits)
   return z;
 }
 
-//! @brief PROC long long mpfr = (LONG LONG REAL) LONG LONG REAL
+//! @brief PROC mpfr_mp = (LONG LONG REAL) LONG LONG REAL
 
 void genie_mpfr_mp (NODE_T * p)
 {
   MOID_T *mode = MOID (p);
-  int digits = DIGITS (mode);
-  int size = SIZE (mode);
-  mpfr_t u;
+  int digits = DIGITS (mode), size = SIZE (mode);
   MP_T *z = (MP_T *) STACK_OFFSET (-size);
+  mpfr_t u;
   mpfr_init2 (u, MPFR_MP_BITS);
   mp_to_mpfr (p, z, &u, digits);
   mpfr_out_str (stdout, 10, 0, u, DEFAULT);
@@ -152,14 +151,14 @@ void genie_mpfr_mp (NODE_T * p)
 
 //! @brief mpfr_beta_inc
 
-void mpfr_beta_inc (mpfr_t I, mpfr_t s, mpfr_t t, mpfr_t x, mpfr_rnd_t rnd)
+void mpfr_beta_inc (mpfr_t Ix, mpfr_t s, mpfr_t t, mpfr_t x, mpfr_rnd_t rnd)
 {
 // Incomplete beta function I{x}(s, t).
 // From a continued fraction, see dlmf.nist.gov/8.17; Lentz's algorithm.
   errno = EDOM;                 // Until proven otherwise
 //mpfr_printf ("%.128Rf", x);
   if (mpfr_cmp_d (x, 0) < 0 || mpfr_cmp_d (x, 1) > 0) {
-    mpfr_set_nan (I);
+    mpfr_set_nan (Ix);
   } else {
     mpfr_t a, b, c, d, e, F, T, W;
     int N, m, cont = A68_TRUE;
@@ -174,8 +173,8 @@ void mpfr_beta_inc (mpfr_t I, mpfr_t s, mpfr_t t, mpfr_t x, mpfr_rnd_t rnd)
     if (mpfr_cmp (x, c) > 0) {
 // B{x}(s, t) = 1 - B{1-x}(t, s)
       mpfr_d_sub (d, 1, x, rnd);
-      mpfr_beta_inc (I, t, s, d, rnd);
-      mpfr_d_sub (I, 1, I, rnd);
+      mpfr_beta_inc (Ix, t, s, d, rnd);
+      mpfr_d_sub (Ix, 1, Ix, rnd);
       mpfr_clears (a, b, c, d, e, F, T, W, NO_MPFR);
       return;
     }
@@ -238,7 +237,7 @@ void mpfr_beta_inc (mpfr_t I, mpfr_t s, mpfr_t t, mpfr_t x, mpfr_rnd_t rnd)
     mpfr_mul (b, F, a, rnd);
     mpfr_div (b, b, W, rnd);
     mpfr_div (b, b, s, rnd);
-    mpfr_set (I, b, rnd);
+    mpfr_set (Ix, b, rnd);
     mpfr_clears (a, b, c, d, e, F, T, W, NO_MPFR);
   }
 }
@@ -250,8 +249,8 @@ void genie_mpfr_erf_mp (NODE_T * p)
   MOID_T *mode = MOID (p);
   int digits = DIGITS (mode);
   int size = SIZE (mode);
-  mpfr_t u;
   MP_T *z = (MP_T *) STACK_OFFSET (-size);
+  mpfr_t u;
   mpfr_init2 (u, MPFR_MP_BITS);
   mp_to_mpfr (p, z, &u, digits);
   mpfr_erf (u, u, DEFAULT);
@@ -267,8 +266,8 @@ void genie_mpfr_erfc_mp (NODE_T * p)
   MOID_T *mode = MOID (p);
   int digits = DIGITS (mode);
   int size = SIZE (mode);
-  mpfr_t u;
   MP_T *z = (MP_T *) STACK_OFFSET (-size);
+  mpfr_t u;
   mpfr_init2 (u, MPFR_MP_BITS);
   mp_to_mpfr (p, z, &u, digits);
   mpfr_erfc (u, u, DEFAULT);
@@ -284,12 +283,11 @@ void genie_mpfr_inverf_mp (NODE_T * _p_)
   MOID_T *mode = MOID (_p_);
   int digits = DIGITS (mode), size = SIZE (mode);
   REAL_T x0;
-  mpfr_t a, b, u, y;
   MP_T *z = (MP_T *) STACK_OFFSET (-size);
-  A68 (f_entry) = _p_;
+  mpfr_t a, b, u, y;
   mpfr_inits2 (MPFR_MP_BITS, a, b, u, y, NO_MPFR);
   mp_to_mpfr (_p_, z, &y, digits);
-  x0 = a68_inverf (mp_to_real (_p_, z, digits));
+  x0 = a68_inverf_real (mp_to_real (_p_, z, digits));
 //  a = z - 1e-9;
 //  b = z + 1e-9;
   mpfr_set_d (a, x0 - 1e-9, DEFAULT);
@@ -320,8 +318,8 @@ void genie_gamma_mpfr (NODE_T * p)
   MOID_T *mode = MOID (p);
   int digits = DIGITS (mode);
   int size = SIZE (mode);
-  mpfr_t u;
   MP_T *z = (MP_T *) STACK_OFFSET (-size);
+  mpfr_t u;
   mpfr_init2 (u, MPFR_MP_BITS);
   mp_to_mpfr (p, z, &u, digits);
   mpfr_gamma (u, u, DEFAULT);
@@ -337,8 +335,8 @@ void genie_lngamma_mpfr (NODE_T * p)
   MOID_T *mode = MOID (p);
   int digits = DIGITS (mode);
   int size = SIZE (mode);
-  mpfr_t u;
   MP_T *z = (MP_T *) STACK_OFFSET (-size);
+  mpfr_t u;
   mpfr_init2 (u, MPFR_MP_BITS);
   mp_to_mpfr (p, z, &u, digits);
   mpfr_lngamma (u, u, DEFAULT);
@@ -350,10 +348,10 @@ void genie_lngamma_mpfr (NODE_T * p)
 void genie_gamma_inc_real_mpfr (NODE_T * p)
 {
   A68_REAL x, s;
-  mpfr_t xx, ss;
   POP_OBJECT (p, &x, A68_REAL);
   POP_OBJECT (p, &s, A68_REAL);
-  mpfr_inits2 (MPFR_LONG_REAL_BITS, ss, xx, NO_MPFR);
+  mpfr_t xx, ss;
+  mpfr_inits2 (A68_DOUBLE_MAN, ss, xx, NO_MPFR);
   mpfr_set_d (xx, VALUE (&x), DEFAULT);
   mpfr_set_d (ss, VALUE (&s), DEFAULT);
   mpfr_gamma_inc (ss, ss, xx, DEFAULT);
@@ -362,13 +360,13 @@ void genie_gamma_inc_real_mpfr (NODE_T * p)
   mpfr_clears (ss, xx, NO_MPFR);
 }
 
-void genie_gamma_inc_real_16_mpfr (NODE_T * p)
+void genie_gamma_inc_double_mpfr (NODE_T * p)
 {
   A68_LONG_REAL x, s;
-  mpfr_t xx, ss;
   POP_OBJECT (p, &x, A68_LONG_REAL);
   POP_OBJECT (p, &s, A68_LONG_REAL);
-  mpfr_inits2 (MPFR_LONG_REAL_BITS, ss, xx, NO_MPFR);
+  mpfr_t xx, ss;
+  mpfr_inits2 (A68_DOUBLE_MAN, ss, xx, NO_MPFR);
   mpfr_set_float128 (xx, VALUE (&x).f, DEFAULT);
   mpfr_set_float128 (ss, VALUE (&s).f, DEFAULT);
   mpfr_gamma_inc (ss, ss, xx, DEFAULT);
@@ -382,8 +380,8 @@ void genie_gamma_inc_mpfr (NODE_T * p)
   int digits = DIGITS (MOID (p)), size = SIZE (MOID (p));
   MP_T *x = (MP_T *) STACK_OFFSET (-size);
   MP_T *s = (MP_T *) STACK_OFFSET (-2 * size);
-  mpfr_t xx, ss;
   A68_SP -= size;
+  mpfr_t xx, ss;
   mpfr_inits2 (MPFR_MP_BITS, ss, xx, NO_MPFR);
   mp_to_mpfr (p, x, &xx, digits);
   mp_to_mpfr (p, s, &ss, digits);
@@ -398,8 +396,8 @@ void genie_beta_mpfr (NODE_T * p)
   int digits = DIGITS (MOID (p)), size = SIZE (MOID (p));
   MP_T *x = (MP_T *) STACK_OFFSET (-size);
   MP_T *s = (MP_T *) STACK_OFFSET (-2 * size);
-  mpfr_t xx, ss;
   A68_SP -= size;
+  mpfr_t xx, ss;
   mpfr_inits2 (MPFR_MP_BITS, ss, xx, NO_MPFR);
   mp_to_mpfr (p, x, &xx, digits);
   mp_to_mpfr (p, s, &ss, digits);
@@ -414,8 +412,8 @@ void genie_ln_beta_mpfr (NODE_T * p)
   int digits = DIGITS (MOID (p)), size = SIZE (MOID (p));
   MP_T *b = (MP_T *) STACK_OFFSET (-size);
   MP_T *a = (MP_T *) STACK_OFFSET (-2 * size);
-  mpfr_t bb, aa, yy, zz;
   A68_SP -= size;
+  mpfr_t bb, aa, yy, zz;
   mpfr_inits2 (MPFR_MP_BITS, aa, bb, yy, zz, NO_MPFR);
   mp_to_mpfr (p, b, &bb, digits);
   mp_to_mpfr (p, a, &aa, digits);
@@ -436,8 +434,8 @@ void genie_beta_inc_mpfr (NODE_T * p)
   MP_T *x = (MP_T *) STACK_OFFSET (-size);
   MP_T *t = (MP_T *) STACK_OFFSET (-2 * size);
   MP_T *s = (MP_T *) STACK_OFFSET (-3 * size);
-  mpfr_t xx, ss, tt;
   A68_SP -= 2 * size;
+  mpfr_t xx, ss, tt;
   mpfr_inits2 (MPFR_MP_BITS, ss, tt, xx, NO_MPFR);
   mp_to_mpfr (p, x, &xx, digits);
   mp_to_mpfr (p, s, &ss, digits);
@@ -454,8 +452,7 @@ void zeroin_mpfr (NODE_T * _p_, mpfr_t * z, mpfr_t a, mpfr_t b, mpfr_t y, int (*
 {
 // 'zeroin'
 // MCA 2310 in 'ALGOL 60 Procedures in Numerical Algebra' by Th.J. Dekker
-  int sign, its = 5;
-  BOOL_T go_on = A68_TRUE;
+  BOOL_T siga = A68_TRUE;
   mpfr_t c, fa, fb, fc, tolb, eps, p, q, v, w;
   mpfr_inits2 (MPFR_MP_BITS, c, fa, fb, fc, tolb, eps, p, q, v, w, NO_MPFR);
   mpfr_set_ui (eps, 10, DEFAULT);
@@ -466,7 +463,8 @@ void zeroin_mpfr (NODE_T * _p_, mpfr_t * z, mpfr_t a, mpfr_t b, mpfr_t y, int (*
   mpfr_sub (fb, fb, y, DEFAULT);
   mpfr_set (c, a, DEFAULT);
   mpfr_set (fc, fa, DEFAULT);
-  while (go_on && (its--) > 0) {
+  int iter = 5;
+  while (siga && (iter--) > 0) {
     mpfr_abs (v, fc, DEFAULT);
     mpfr_abs (w, fb, DEFAULT);
     if (mpfr_cmp (v, w) < 0) {
@@ -484,8 +482,8 @@ void zeroin_mpfr (NODE_T * _p_, mpfr_t * z, mpfr_t a, mpfr_t b, mpfr_t y, int (*
     mpfr_div_2ui (w, w, 1, DEFAULT);
     mpfr_sub (v, w, b, DEFAULT);
     mpfr_abs (v, v, DEFAULT);
-    go_on = mpfr_cmp (v, tolb) > 0;
-    if (go_on) {
+    siga = mpfr_cmp (v, tolb) > 0;
+    if (siga) {
       mpfr_sub (p, b, a, DEFAULT);
       mpfr_mul (p, p, fb, DEFAULT);
       mpfr_sub (q, fa, fb, DEFAULT);
@@ -515,7 +513,7 @@ void zeroin_mpfr (NODE_T * _p_, mpfr_t * z, mpfr_t a, mpfr_t b, mpfr_t y, int (*
       }
       f (fb, b, DEFAULT);
       mpfr_sub (fb, fb, y, DEFAULT);
-      sign = mpfr_sgn (fb) + mpfr_sgn (fc);
+      int sign = mpfr_sgn (fb) + mpfr_sgn (fc);
       if (ABS (sign) == 2) {
         mpfr_set (c, a, DEFAULT);
         mpfr_set (fc, fa, DEFAULT);
