@@ -1,194 +1,174 @@
 //! @file single-gsl.c
 //! @author J. Marcel van der Veer
-//
+
 //! @section Copyright
-//
-// This file is part of Algol68G - an Algol 68 compiler-interpreter.
-// Copyright 2001-2023 J. Marcel van der Veer <algol68g@xs4all.nl>.
-//
+//!
+//! This file is part of Algol68G - an Algol 68 compiler-interpreter.
+//! Copyright 2001-2025 J. Marcel van der Veer [algol68g@xs4all.nl].
+
 //! @section License
-//
-// This program is free software; you can redistribute it and/or modify it 
-// under the terms of the GNU General Public License as published by the 
-// Free Software Foundation; either version 3 of the License, or 
-// (at your option) any later version.
-//
-// This program is distributed in the hope that it will be useful, but 
-// WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY 
-// or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for 
-// more details. You should have received a copy of the GNU General Public 
-// License along with this program. If not, see <http://www.gnu.org/licenses/>.
+//!
+//! This program is free software; you can redistribute it and/or modify it 
+//! under the terms of the GNU General Public License as published by the 
+//! Free Software Foundation; either version 3 of the License, or 
+//! (at your option) any later version.
+//!
+//! This program is distributed in the hope that it will be useful, but 
+//! WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY 
+//! or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for 
+//! more details. You should have received a copy of the GNU General Public 
+//! License along with this program. If not, see [http://www.gnu.org/licenses/].
+
+//! @section Synopsis
+//!
+//! REAL GSL routines.
 
 #include "a68g.h"
 #include "a68g-genie.h"
 #include "a68g-prelude.h"
 #include "a68g-prelude-gsl.h"
-#include "a68g-double.h"
-#include "a68g-numbers.h"
 
 #if defined (HAVE_GSL)
 
+//! @brief Convert VECTOR to [] REAL.
+
 #define PROC_RR_R(p, g, f)\
 void g (NODE_T *p) {\
-  A68 (f_entry) = p;\
   A68_REAL *x;\
-  int status;\
   POP_OPERAND_ADDRESS (p, x, A68_REAL);\
   (void) gsl_set_error_handler_off ();\
-  status = f (& (VALUE (x)));\
+  int status = f (& (VALUE (x)));\
   MATH_RTE (p, status != 0, M_REAL, (char *) gsl_strerror (status));\
 }
 
 #define PROC_R_R(p, g, f)\
 void g (NODE_T *p) {\
-  A68 (f_entry) = p;\
   A68_REAL *x;\
-  gsl_sf_result y;\
-  int status;\
   POP_OPERAND_ADDRESS (p, x, A68_REAL);\
   (void) gsl_set_error_handler_off ();\
-  status = f (VALUE (x), &y);\
+  gsl_sf_result y;\
+  int status = f (VALUE (x), &y);\
   MATH_RTE (p, status != 0, M_REAL, (char *) gsl_strerror (status));\
   VALUE (x) = VAL (&y);\
 }
 
 #define PROC_R_R_DBL(p, g, f)\
 void g (NODE_T *p) {\
-  A68 (f_entry) = p;\
   A68_REAL *x;\
-  gsl_sf_result y;\
-  int status;\
   POP_OPERAND_ADDRESS (p, x, A68_REAL);\
   (void) gsl_set_error_handler_off ();\
-  status = f (VALUE (x), GSL_PREC_DOUBLE, &y);\
+  gsl_sf_result y;\
+  int status = f (VALUE (x), GSL_PREC_DOUBLE, &y);\
   MATH_RTE (p, status != 0, M_REAL, (char *) gsl_strerror (status));\
   VALUE (x) = VAL (&y);\
 }
 
 #define PROC_I_R(p, g, f)\
 void g (NODE_T *p) {\
-  A68 (f_entry) = p;\
   A68_INT s;\
-  gsl_sf_result y;\
-  int status;\
   POP_OBJECT (p, &s, A68_INT);\
   (void) gsl_set_error_handler_off ();\
-  status = f (VALUE (&s), &y);\
+  gsl_sf_result y;\
+  int status = f (VALUE (&s), &y);\
   MATH_RTE (p, status != 0, M_REAL, (char *) gsl_strerror (status));\
   PUSH_VALUE (p, VAL (&y), A68_REAL);\
 }
 
 #define PROC_R_R_R(p, g, f)\
 void g (NODE_T *p) {\
-  A68 (f_entry) = p;\
   A68_REAL *x, *y;\
-  gsl_sf_result r;\
-  int status;\
   POP_OPERAND_ADDRESSES (p, x, y, A68_REAL);\
   (void) gsl_set_error_handler_off ();\
-  status = f (VALUE (x), VALUE (y),  &r);\
+  gsl_sf_result r;\
+  int status = f (VALUE (x), VALUE (y),  &r);\
   MATH_RTE (p, status != 0, M_REAL, (char *) gsl_strerror (status));\
   VALUE (x) = VAL (&r);\
 }
 
 #define PROC_I_R_R(p, g, f)\
 void g (NODE_T *p) {\
-  A68 (f_entry) = p;\
-  A68_INT s;\
   A68_REAL x;\
-  gsl_sf_result r;\
-  int status;\
   POP_OBJECT (p, &x, A68_REAL);\
+  A68_INT s;\
   POP_OBJECT (p, &s, A68_INT);\
   (void) gsl_set_error_handler_off ();\
-  status = f (VALUE (&s), VALUE (&x), &r);\
+  gsl_sf_result r;\
+  int status = f (VALUE (&s), VALUE (&x), &r);\
   MATH_RTE (p, status != 0, M_REAL, (char *) gsl_strerror (status));\
   PUSH_VALUE (p, VAL (&r), A68_REAL);\
 }
 
 #define PROC_I_R_R_REVERSED(p, g, f)\
 void g (NODE_T *p) {\
-  A68 (f_entry) = p;\
-  A68_INT s;\
   A68_REAL x;\
-  gsl_sf_result r;\
-  int status;\
   POP_OBJECT (p, &x, A68_REAL);\
+  A68_INT s;\
   POP_OBJECT (p, &s, A68_INT);\
   (void) gsl_set_error_handler_off ();\
-  status = f (VALUE (&x), VALUE (&s), &r);\
+  gsl_sf_result r;\
+  int status = f (VALUE (&x), VALUE (&s), &r);\
   MATH_RTE (p, status != 0, M_REAL, (char *) gsl_strerror (status));\
   PUSH_VALUE (p, VAL (&r), A68_REAL);\
 }
 
 #define PROC_R_R_R_DBL(p, g, f)\
 void g (NODE_T *p) {\
-  A68 (f_entry) = p;\
   A68_REAL *x, *y;\
-  gsl_sf_result r;\
-  int status;\
   POP_OPERAND_ADDRESSES (p, x, y, A68_REAL);\
   (void) gsl_set_error_handler_off ();\
-  status = f (VALUE (x), VALUE (y), GSL_PREC_DOUBLE, &r);\
+  gsl_sf_result r;\
+  int status = f (VALUE (x), VALUE (y), GSL_PREC_DOUBLE, &r);\
   MATH_RTE (p, status != 0, M_REAL, (char *) gsl_strerror (status));\
   VALUE (x) = VAL (&r);\
 }
 
 #define PROC_R_R_R_R(p, g, f)\
 void g (NODE_T *p) {\
-  A68 (f_entry) = p;\
   A68_REAL *x, *y, *z;\
-  gsl_sf_result r;\
-  int status;\
   POP_ADDRESS (p, z, A68_REAL);\
   POP_OPERAND_ADDRESSES (p, x, y, A68_REAL);\
   (void) gsl_set_error_handler_off ();\
-  status = f (VALUE (x), VALUE (y), VALUE (z),  &r);\
+  gsl_sf_result r;\
+  int status = f (VALUE (x), VALUE (y), VALUE (z),  &r);\
   MATH_RTE (p, status != 0, M_REAL, (char *) gsl_strerror (status));\
   VALUE (x) = VAL (&r);\
 }
 
 #define PROC_I_R_R_R(p, g, f)\
 void g (NODE_T *p) {\
-  A68 (f_entry) = p;\
-  A68_INT s;\
   A68_REAL x, y;\
-  gsl_sf_result r;\
-  int status;\
   POP_OBJECT (p, &y, A68_REAL);\
   POP_OBJECT (p, &x, A68_REAL);\
+  A68_INT s;\
   POP_OBJECT (p, &s, A68_INT);\
   (void) gsl_set_error_handler_off ();\
-  status = f (VALUE (&s), VALUE (&x), VALUE (&y), &r);\
+  gsl_sf_result r;\
+  int status = f (VALUE (&s), VALUE (&x), VALUE (&y), &r);\
   MATH_RTE (p, status != 0, M_REAL, (char *) gsl_strerror (status));\
   PUSH_VALUE (p, VAL (&r), A68_REAL);\
 }
 
 #define PROC_R_R_R_R_DBL(p, g, f)\
 void g (NODE_T *p) {\
-  A68 (f_entry) = p;\
   A68_REAL *x, *y, *z;\
-  gsl_sf_result r;\
-  int status;\
   POP_ADDRESS (p, z, A68_REAL);\
   POP_OPERAND_ADDRESSES (p, x, y, A68_REAL);\
   (void) gsl_set_error_handler_off ();\
-  status = f (VALUE (x), VALUE (y), VALUE (z), GSL_PREC_DOUBLE, &r);\
+  gsl_sf_result r;\
+  int status = f (VALUE (x), VALUE (y), VALUE (z), GSL_PREC_DOUBLE, &r);\
   MATH_RTE (p, status != 0, M_REAL, (char *) gsl_strerror (status));\
   VALUE (x) = VAL (&r);\
 }
 
 #define PROC_R_R_R_R_R_DBL(p, g, f)\
 void g (NODE_T *p) {\
-  A68 (f_entry) = p;\
   A68_REAL *x, *y, *z, *rho;\
-  gsl_sf_result r;\
-  int status;\
   POP_ADDRESS (p, rho, A68_REAL);\
   POP_ADDRESS (p, z, A68_REAL);\
   POP_OPERAND_ADDRESSES (p, x, y, A68_REAL);\
   (void) gsl_set_error_handler_off ();\
-  status = f (VALUE (x), VALUE (y), VALUE (z), VALUE (rho), GSL_PREC_DOUBLE, &r);\
+  gsl_sf_result r;\
+  int status = f (VALUE (x), VALUE (y), VALUE (z), VALUE (rho), GSL_PREC_DOUBLE, &r);\
   MATH_RTE (p, status != 0, M_REAL, (char *) gsl_strerror (status));\
   VALUE (x) = VAL (&r);\
 }
